==> mumble_1.1.8.orig.tar.gz: mumble-1.1.8/src/mumble/ALSAAudio.h <==
/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>

   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright notice,
     this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright notice,
     this list of conditions and the following disclaimer in the documentation
     and/or other materials provided with the distribution.
   - Neither the name of the Mumble Developers nor the names of its
     contributors may be used to endorse or promote products derived from this
     software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef _ALSAAUDIO_H
#define _ALSAAUDIO_H

#include "AudioInput.h"
#include "AudioOutput.h"
#include "ConfigDialog.h"
#include <alsa/asoundlib.h>

class ALSAAudioOutput;
class ALSAAudioInput;

class ALSAAudioInput : public AudioInput {
	private:
		Q_OBJECT
		Q_DISABLE_COPY(ALSAAudioInput)
	public:
		ALSAAudioInput();
		~ALSAAudioInput();
		void run();
};

class ALSAAudioOutput : public AudioOutput {
	private:
		Q_OBJECT
		Q_DISABLE_COPY(ALSAAudioOutput)
	protected:
	public:
		ALSAAudioOutput();
		~ALSAAudioOutput();
		void run();
};

#else
class ALSAAudioInput;
class ALSAAudioOutput;
#endif

==> mumble_1.2.4.orig.tar.gz: mumble-1.2.4/src/mumble/ALSAAudio.h <==
/* Copyright (C) 2005-2011, Thorvald Natvig <thorvald@natvig.com>

   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright notice,
     this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright notice,
     this list of conditions and the following disclaimer in the documentation
     and/or other materials provided with the distribution.
   - Neither the name of the Mumble Developers nor the names of its
     contributors may be used to endorse or promote products derived from this
     software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef ALSAAUDIO_H_
#define ALSAAUDIO_H_

#include "AudioInput.h"
#include "AudioOutput.h"

class ALSAAudioOutput;
class ALSAAudioInput;

class ALSAAudioInput : public AudioInput {
	private:
		Q_OBJECT
		Q_DISABLE_COPY(ALSAAudioInput)
	public:
		ALSAAudioInput();
		~ALSAAudioInput();
		void run();
};

class ALSAAudioOutput : public AudioOutput {
	private:
		Q_OBJECT
		Q_DISABLE_COPY(ALSAAudioOutput)
	protected:
	public:
		ALSAAudioOutput();
		~ALSAAudioOutput();
		void run();
};

#else
class ALSAAudioInput;
class ALSAAudioOutput;
#endif
